@@ -230,6 +230,7 @@ KateCompletionConfigTab::KateCompletionConfigTab(QWidget *parent)
     observeChanges(ui->chkAutoCompletionEnabled);
     observeChanges(ui->chkAutoSelectFirstEntry);
     observeChanges(ui->chkTabCompletion);
+    observeChanges(ui->chkEnterCompletion);
     observeChanges(ui->gbKeywordCompletion);
     observeChanges(ui->gbShowDoc);
     observeChanges(ui->gbWordCompletion);
@@ -262,6 +263,7 @@ void KateCompletionConfigTab::apply()
     KateViewConfig::global()->setValue(KateViewConfig::AutomaticCompletionInvocation, ui->chkAutoCompletionEnabled->isChecked());
     KateViewConfig::global()->setValue(KateViewConfig::AutomaticCompletionPreselectFirst, ui->chkAutoSelectFirstEntry->isChecked());
     KateViewConfig::global()->setValue(KateViewConfig::TabCompletion, ui->chkTabCompletion->isChecked());
+    KateViewConfig::global()->setValue(KateViewConfig::EnterToInsertCompletion, ui->chkEnterCompletion->isChecked());
     KateViewConfig::global()->setValue(KateViewConfig::KeywordCompletion, ui->gbKeywordCompletion->isChecked());
     KateViewConfig::global()->setValue(KateViewConfig::WordCompletion, ui->gbWordCompletion->isChecked());
     KateViewConfig::global()->setValue(KateViewConfig::WordCompletionMinimalWordLength, ui->minimalWordLength->value());
@@ -276,6 +278,7 @@ void KateCompletionConfigTab::reload()
     ui->chkAutoCompletionEnabled->setChecked(KateViewConfig::global()->automaticCompletionInvocation());
     ui->chkAutoSelectFirstEntry->setChecked(KateViewConfig::global()->automaticCompletionPreselectFirst());
     ui->chkTabCompletion->setChecked(KateViewConfig::global()->tabCompletion());
+    ui->chkEnterCompletion->setChecked(KateViewConfig::global()->value(KateViewConfig::EnterToInsertCompletion).toBool());
 
     ui->gbKeywordCompletion->setChecked(KateViewConfig::global()->keywordCompletion());
     ui->gbWordCompletion->setChecked(KateViewConfig::global()->wordCompletion());
@@ -1544,7 +1547,7 @@ void KateModOnHdPrompt::slotPDone()
     m_proc = nullptr;
 
     if (es != QProcess::NormalExit) {
-        KMessageBox::error(nullptr,
+        KMessageBox::error(m_doc->activeView(),
                            i18n("The diff command failed. Please make sure that "
                                 "diff(1) is installed and in your PATH."),
                            i18n("Error Creating Diff"));
@@ -1554,7 +1557,7 @@ void KateModOnHdPrompt::slotPDone()
     }
 
     if (m_diffFile->size() == 0) {
-        KMessageBox::information(nullptr, i18n("The files are identical."), i18n("Diff Output"));
+        KMessageBox::information(m_doc->activeView(), i18n("The files are identical."), i18n("Diff Output"));
         delete m_diffFile;
         m_diffFile = nullptr;
         return;
