@@ -36,6 +36,7 @@ namespace Kate
 class TextCursor;
 }
 class KateBookmarks;
+class KateRendererConfig;
 class KateViewConfig;
 class KateRenderer;
 class KateSpellCheckDialog;
@@ -120,7 +121,7 @@ public:
 public Q_SLOTS:
     void paste(const QString *textToPaste = nullptr);
     void cut();
-    void copy() const;
+    void copy();
     void screenshot();
 
 private Q_SLOTS:
@@ -655,6 +656,7 @@ public Q_SLOTS:
     void shiftWordLeft();
     void wordRight();
     void shiftWordRight();
+    void markSelection();
     void home();
     void shiftHome();
     void end();
@@ -753,6 +755,7 @@ public:
 
 public:
     KateRenderer *renderer();
+    KateRendererConfig *rendererConfig();
 
     bool iconBorder();
     bool lineNumbersOn();
@@ -761,7 +764,7 @@ public:
     bool scrollBarMiniMapAll();
     int dynWrapIndicators();
     bool foldingMarkersOn();
-    bool forceRTLDirection();
+    bool forceRTLDirection() const;
 
 private Q_SLOTS:
     /**
@@ -850,6 +853,7 @@ private:
     QAction *m_editUndo;
     QAction *m_editRedo;
     bool m_gotoBottomAfterReload;
+    bool m_markedSelection;
     KToggleAction *m_toggleFoldingMarkers;
     KToggleAction *m_toggleIconBar;
     KToggleAction *m_toggleLineNumbers;
